# TypeEnum

* `ForestNotice` - ForestNotice * `WithoutForestNotice` - WithoutForestNotice * `InventoryAct` - InventoryAct * `ConsolidatedAct` - ConsolidatedAct * `ForestAct` - ForestAct * `SalesContract` - SalesContract * `ContractForTransferOfCuttingRights` - ContractForTransferOfCuttingRights

## Enum

* `FORESTNOTICE` (value: `'ForestNotice'`)

* `WITHOUTFORESTNOTICE` (value: `'WithoutForestNotice'`)

* `INVENTORYACT` (value: `'InventoryAct'`)

* `CONSOLIDATEDACT` (value: `'ConsolidatedAct'`)

* `FORESTACT` (value: `'ForestAct'`)

* `SALESCONTRACT` (value: `'SalesContract'`)

* `CONTRACTFORTRANSFEROFCUTTINGRIGHTS` (value: `'ContractForTransferOfCuttingRights'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


